import { aws_ec2 as ec2, aws_ecs as ecs, aws_elasticloadbalancingv2 as elbv2, aws_iam as iam } from "aws-cdk-lib";
import { ICertificate } from "aws-cdk-lib/aws-certificatemanager";
import { Construct } from "constructs";
/**
 * Configuration for ECS service auto-scaling.
 */
export interface AutoScalingProps {
    /** Minimum number of tasks to run. */
    readonly minCapacity: number;
    /** Maximum number of tasks to run. */
    readonly maxCapacity: number;
    /** Target average CPU utilization percentage across tasks. */
    readonly targetCpuUtilizationPercent: number;
    /** Cooldown period (in seconds) after a scale-in activity. */
    readonly scaleInCooldownSec?: number;
    /** Cooldown period (in seconds) after a scale-out activity. */
    readonly scaleOutCooldownSec?: number;
}
/**
 * Configuration for the ECS Fargate task definition and container.
 */
export interface TaskProps {
    /** CPU units for the task (default: 1024). */
    readonly cpu?: number;
    /** Hard memory limit in MiB for the task (default: 2048). */
    readonly memoryLimitMiB?: number;
    /** Soft memory reservation in MiB for the container (default: 1024). */
    readonly memoryReservationMiB?: number;
    /** The port number the container listens on. */
    readonly containerPort: number;
    /** Container image to deploy. */
    readonly image: ecs.ContainerImage;
    /** Optional container health check configuration. */
    readonly healthCheck?: ecs.HealthCheck;
}
/**
 * Configuration for the Application Load Balancer.
 */
export interface LoadBalancerProps {
    /** Whether the load balancer should be internet-facing (default: false). */
    readonly enablePublicLoadBalancer?: boolean;
    /** Optional ACM certificates for HTTPS termination. */
    readonly certificates?: ICertificate[];
}
/**
 * Properties for the EcsCodeDeploy construct.
 */
export interface EcsCodeDeployProps {
    /** VPC in which to deploy ECS and ALB resources. */
    readonly vpc: ec2.IVpc;
    /** ECS Cluster where the service will run. */
    readonly cluster: ecs.ICluster;
    /** Environment name (e.g., dev, prod) for tagging and naming. */
    readonly environment: string;
    /** Base name used for resources like log groups, roles, services, etc. */
    readonly serviceName: string;
    /** Configuration related to the task definition and container. */
    readonly task: TaskProps;
    /** Optional load balancer configuration. */
    readonly loadBalancer?: LoadBalancerProps;
    /** Optional auto-scaling configuration. */
    readonly autoScaling?: AutoScalingProps;
}
export declare class EcsCodeDeploy extends Construct {
    readonly service: ecs.FargateService;
    readonly loadBalancer: elbv2.ApplicationLoadBalancer;
    readonly taskDef: ecs.TaskDefinition;
    readonly taskRole: iam.Role;
    readonly taskExecRole: iam.Role;
    constructor(scope: Construct, id: string, props: EcsCodeDeployProps);
}
